# 2021-10-12 - Merkle Orchard

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This distributor has been deprecated in favor of the veBAL system.
> A patched version of the orchard can be found [here](../../20230222-merkle-orchard-v2), which fixes the double-claim issue described in [this report](https://medium.com/immunefi/balancer-logic-error-bugfix-review-74f5edca8b1a)

Deployment of the `MerkleOrchard`, for distributing tokens via Merkle Trees

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`MerkleOrchard` artifact](./artifact/MerkleOrchard.json)
